@@ -1,6 +1,6 @@
  /***************************************************************************\
 |*                                                                           *|
-|*       Copyright 1993-2017 NVIDIA, Corporation.  All rights reserved.      *|
+|*       Copyright 1993-2019 NVIDIA, Corporation.  All rights reserved.      *|
 |*                                                                           *|
 |*     NOTICE TO USER:   The source code  is copyrighted under  U.S. and     *|
 |*     international laws.  Users and possessors of this source code are     *|
@@ -11,7 +11,7 @@
 |*     tion and  internal comments to the code,  notices to the end user     *|
 |*     as follows:                                                           *|
 |*                                                                           *|
-|*       Copyright 1993-2015 NVIDIA, Corporation.  All rights reserved.      *|
+|*       Copyright 1993-2018 NVIDIA, Corporation.  All rights reserved.      *|
 |*                                                                           *|
 |*     NVIDIA, CORPORATION MAKES NO REPRESENTATION ABOUT THE SUITABILITY     *|
 |*     OF  THIS SOURCE  CODE  FOR ANY PURPOSE.  IT IS  PROVIDED  "AS IS"     *|
@@ -266,8 +266,8 @@ typedef NvU8 NvTristate;
 #define NvU40_HI24of32(n) ((NvU32)(  (NvU64)(n)         & 0xffffff00U))
 
 /* Macros to get the MSB and LSB of a 32 bit unsigned number */
-#define NvU32_HI16(n)     ((NvU16)((((NvU32)(n)) >> 16) & 0xffff))
-#define NvU32_LO16(n)     ((NvU16)(( (NvU32)(n))        & 0xffff))
+#define NvU32_HI16(n)     ((NvU16)((((NvU32)(n)) >> 16) & 0xffffU))
+#define NvU32_LO16(n)     ((NvU16)(( (NvU32)(n))        & 0xffffU))
 
  /***************************************************************************\
 |*                                                                           *|
@@ -329,7 +329,7 @@ typedef NvU32           NvLength; /* length to agree with sizeof             */
 do {                                                                           \
     (pDst)->lo = NvU64_LO32(*(pSrc));                                          \
     (pDst)->hi = NvU64_HI32(*(pSrc));                                          \
-} while (0)
+} while (NV_FALSE)
 
 /*!
  * Helper macro to unpack a @ref NvU64_ALIGN32 structure into a @ref NvU64.
@@ -340,7 +340,7 @@ do {                                                                           \
 #define NvU64_ALIGN32_UNPACK(pDst, pSrc)                                       \
 do {                                                                           \
     (*pDst) = NvU64_ALIGN32_VAL(pSrc);                                         \
-} while (0)
+} while (NV_FALSE)
 
 /*!
  * Helper macro to unpack a @ref NvU64_ALIGN32 structure as a @ref NvU64.
@@ -348,7 +348,7 @@ do {                                                                           \
  * @param[in]  pSrc   Pointer to NvU64_ALIGN32 structure to unpack
  */
 #define NvU64_ALIGN32_VAL(pSrc)                                                \
-    ((NvU64) ((NvU64)((pSrc)->lo) | (((NvU64)(pSrc)->hi) << 32)))
+    ((NvU64) ((NvU64)((pSrc)->lo) | (((NvU64)(pSrc)->hi) << 32U)))
 
 /*!
  * Helper macro to check whether the 32 bit aligned 64 bit number is zero.
@@ -359,7 +359,8 @@ do {                                                                           \
  *  NV_TRUE     _pU64 is zero.
  *  NV_FALSE    otherwise.
  */
-#define NvU64_ALIGN32_IS_ZERO(_pU64)  (((_pU64)->lo == 0) && ((_pU64)->hi == 0))
+#define NvU64_ALIGN32_IS_ZERO(_pU64)                                          \
+    (((_pU64)->lo == 0U) && ((_pU64)->hi == 0U))
 
 /*!
  * Helper macro to sub two 32 aligned 64 bit numbers on 64 bit processor.
@@ -372,11 +373,11 @@ do {                                                                           \
 do {                                                                          \
     NvU64 __dst, __src1, __scr2;                                              \
                                                                               \
-    NvU64_ALIGN32_UNPACK(&__src1, pSrc1);                                     \
-    NvU64_ALIGN32_UNPACK(&__scr2, pSrc2);                                     \
+    NvU64_ALIGN32_UNPACK(&__src1, (pSrc1));                                   \
+    NvU64_ALIGN32_UNPACK(&__scr2, (pSrc2));                                   \
     __dst = __src1 + __scr2;                                                  \
-    NvU64_ALIGN32_PACK(pDst, &__dst);                                         \
-} while (0)
+    NvU64_ALIGN32_PACK((pDst), &__dst);                                       \
+} while (NV_FALSE)
 
 /*!
  * Helper macro to sub two 32 aligned 64 bit numbers on 64 bit processor.
@@ -389,11 +390,11 @@ do {                                                                          \
 do {                                                                           \
     NvU64 __dst, __src1, __scr2;                                               \
                                                                                \
-    NvU64_ALIGN32_UNPACK(&__src1, pSrc1);                                      \
-    NvU64_ALIGN32_UNPACK(&__scr2, pSrc2);                                      \
+    NvU64_ALIGN32_UNPACK(&__src1, (pSrc1));                                    \
+    NvU64_ALIGN32_UNPACK(&__scr2, (pSrc2));                                    \
     __dst = __src1 + __scr2;                                                   \
-    NvU64_ALIGN32_PACK(pDst, &__dst);                                          \
-} while (0)
+    NvU64_ALIGN32_PACK((pDst), &__dst);                                        \
+} while (NV_FALSE)
 
 /*!
  * Structure for representing 32 bit aligned NvU64 (64-bit unsigned integer)
@@ -743,8 +744,8 @@ typedef NvUFXP64                                                   NvUFXP52_12;
 /*!
  * - UNSIGNED - These are only used for unsigned.
  */
-#define NV_TYPES_UFXP_INTEGER_MAX(x, y)                         (~(BIT((y))-1))
-#define NV_TYPES_UFXP_INTEGER_MIN(x, y)                                     (0)
+#define NV_TYPES_UFXP_INTEGER_MAX(x, y)                      (~(NVBIT((y))-1U))
+#define NV_TYPES_UFXP_INTEGER_MIN(x, y)                                    (0U)
 
 /*!
  * - SIGNED - These are only used for signed.
@@ -754,9 +755,9 @@ typedef NvUFXP64                                                   NvUFXP52_12;
 #define NV_TYPES_SFXP_INTEGER_SIGN_POSITIVE                          0x00000000
 #define NV_TYPES_SFXP_S32_SIGN_EXTENSION(x, y)                           31:(x)
 #define NV_TYPES_SFXP_S32_SIGN_EXTENSION_POSITIVE(x, y)              0x00000000
-#define NV_TYPES_SFXP_S32_SIGN_EXTENSION_NEGATIVE(x, y)         (BIT(32-(x))-1)
-#define NV_TYPES_SFXP_INTEGER_MAX(x, y)                            (BIT((x))-1)
-#define NV_TYPES_SFXP_INTEGER_MIN(x, y)                         (~(BIT((x))-1))
+#define NV_TYPES_SFXP_S32_SIGN_EXTENSION_NEGATIVE(x, y)      (NVBIT(32-(x))-1U)
+#define NV_TYPES_SFXP_INTEGER_MAX(x, y)                         (NVBIT((x))-1U)
+#define NV_TYPES_SFXP_INTEGER_MIN(x, y)                      (~(NVBIT((x))-1U))
 
 /*!
  * Conversion macros used for converting between integer and fixed point
@@ -789,7 +790,7 @@ typedef NvUFXP64                                                   NvUFXP52_12;
                             (scale)) +                                        \
                         ((((((NvU32) (integer)) <<                            \
                             DRF_SHIFT(NV_TYPES_FXP_INTEGER((x), (y)))) %      \
-                                (scale)) > ((scale) / 2)) ? 1 : 0)))
+                                (scale)) > ((scale) >> 1)) ? 1U : 0U)))
 
 #define NV_TYPES_UFXP_X_Y_TO_U32(x, y, fxp)                                   \
     ((NvU32) (DRF_VAL(_TYPES, _FXP, _INTEGER((x), (y)),                       \
@@ -808,7 +809,7 @@ typedef NvUFXP64                                                   NvUFXP52_12;
 #define NV_TYPES_U64_TO_UFXP_X_Y_SCALED(x, y, integer, scale)                 \
     ((NvUFXP##x##_##y) (((((NvU64) (integer)) <<                              \
                              DRF_SHIFT(NV_TYPES_FXP_INTEGER((x), (y)))) +     \
-                         ((scale) / 2)) /                                     \
+                         ((scale) >> 1)) /                                    \
                         (scale)))
 
 #define NV_TYPES_UFXP_X_Y_TO_U64(x, y, fxp)                                   \
@@ -832,7 +833,7 @@ typedef NvUFXP64                                                   NvUFXP52_12;
 #define NV_TYPES_S32_TO_SFXP_X_Y_SCALED(x, y, integer, scale)                 \
     ((NvSFXP##x##_##y) (((((NvS32) (integer)) <<                              \
                              DRF_SHIFT(NV_TYPES_FXP_INTEGER((x), (y)))) +     \
-                         ((scale) / 2)) /                                     \
+                         ((scale) >> 1)) /                                    \
                         (scale)))
 
 #define NV_TYPES_SFXP_X_Y_TO_S32(x, y, fxp)                                   \
@@ -942,7 +943,7 @@ typedef NvSFXP24_8              NvTemp;
 #define NV_TYPES_NVUFXP11_5_WATTS_TO_NVU32_MILLI_WATTS(x) ((((NvU32)(x)) * ((NvU32)1000)) >> 5)
 
 #ifdef __cplusplus
-};
+}
 #endif
 
 #endif /* ! XAPIGEN */
